"""Create initial schema

Revision ID: 37d56eaa8bf6
Revises: 
Create Date: 2018-06-04 16:15:45.104613

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "37d56eaa8bf6"
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    op.create_table(
        "feeds",
        sa.Column("id", sa.String(), nullable=False),
        sa.Column("version", sa.String(), nullable=False),
        sa.Column("name", sa.String(), nullable=True),
        sa.Column("provider_url", sa.String(), nullable=True),
        sa.Column("summary", sa.String(), nullable=True),
        sa.Column("category", sa.String(), nullable=True),
        sa.Column("access", sa.String(), nullable=True),
        sa.Column("timestamp", sa.DateTime(timezone=True), nullable=True),
        sa.PrimaryKeyConstraint("id", "version"),
    )
    op.create_table(
        "alerts",
        sa.Column("org_key", sa.String(), nullable=False),
        sa.Column("feed_id", sa.String(), nullable=False),
        sa.Column("feed_version", sa.String(), nullable=False),
        sa.Column("report_id", sa.String(), nullable=False),
        sa.Column("alert", sa.Boolean(), nullable=True),
        sa.ForeignKeyConstraint(
            ["feed_id", "feed_version"],
            ["feeds.id", "feeds.version"],
            name="alerts_feed_id_fkey",
        ),
        sa.PrimaryKeyConstraint("org_key", "feed_id", "feed_version", "report_id"),
    )
    op.create_table(
        "ignore",
        sa.Column("org_key", sa.String(), nullable=False),
        sa.Column("feed_id", sa.String(), nullable=False),
        sa.Column("feed_version", sa.String(), nullable=False),
        sa.Column("report_id", sa.String(), nullable=False),
        sa.Column("ioc_id", sa.String(), nullable=False),
        sa.ForeignKeyConstraint(
            ["feed_id", "feed_version"],
            ["feeds.id", "feeds.version"],
            name="ignore_feed_id_fkey",
        ),
        sa.PrimaryKeyConstraint(
            "org_key", "feed_id", "feed_version", "report_id", "ioc_id"
        ),
    )
    op.create_table(
        "report_score_overrides",
        sa.Column("org_key", sa.String(), nullable=False),
        sa.Column("feed_id", sa.String(), nullable=False),
        sa.Column("feed_version", sa.String(), nullable=False),
        sa.Column("report_id", sa.String(), nullable=False),
        sa.Column("score", sa.Integer(), nullable=True),
        sa.ForeignKeyConstraint(
            ["feed_id", "feed_version"],
            ["feeds.id", "feeds.version"],
            name="report_score_overrides_feed_id_fkey",
        ),
        sa.PrimaryKeyConstraint("org_key", "feed_id", "feed_version", "report_id"),
    )
    op.create_table(
        "reports",
        sa.Column("id", sa.String(), nullable=False),
        sa.Column("feed_id", sa.String(), nullable=False),
        sa.Column("feed_version", sa.String(), nullable=True),
        sa.Column("timestamp", sa.DateTime(timezone=True), nullable=True),
        sa.Column("link", sa.String(), nullable=True),
        sa.Column("title", sa.String(), nullable=True),
        sa.Column("score", sa.Integer(), nullable=True),
        sa.Column("tags", sa.String(), nullable=True),
        sa.Column("description", sa.String(), nullable=True),
        sa.Column("visibility", sa.String(), nullable=True),
        sa.ForeignKeyConstraint(
            ["feed_id", "feed_version"],
            ["feeds.id", "feeds.version"],
            name="reports_feed_id_fkey",
        ),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_table(
        "subscriptions",
        sa.Column("org_key", sa.String(), nullable=False),
        sa.Column("feed_id", sa.String(), nullable=False),
        sa.Column("feed_version", sa.String(), nullable=False),
        sa.ForeignKeyConstraint(
            ["feed_id", "feed_version"],
            ["feeds.id", "feeds.version"],
            name="subscriptions_feed_id_fkey",
        ),
        sa.PrimaryKeyConstraint("org_key", "feed_id", "feed_version"),
    )
    op.create_table(
        "iocs",
        sa.Column("report_id", sa.String(), nullable=False),
        sa.Column("feed_id", sa.String(), nullable=False),
        sa.Column("feed_version", sa.String(), nullable=True),
        sa.Column("entries", sa.String(), nullable=True),
        sa.ForeignKeyConstraint(
            ["report_id"],
            ["reports.id"],
        ),
        sa.PrimaryKeyConstraint("report_id"),
    )
    op.create_table(
        "iocs_v2",
        sa.Column("id", sa.String(), nullable=False),
        sa.Column("report_id", sa.String(), nullable=False),
        sa.Column("feed_id", sa.String(), nullable=False),
        sa.Column("feed_version", sa.String(), nullable=True),
        sa.Column("match_type", sa.String(), nullable=True),
        sa.Column("field", sa.String(), nullable=True),
        sa.Column("values", sa.String(), nullable=True),
        sa.Column("link", sa.String(), nullable=True),
        sa.ForeignKeyConstraint(
            ["report_id"],
            ["reports.id"],
        ),
        sa.PrimaryKeyConstraint("id"),
    )


def downgrade():  # pragma: no cover
    op.drop_table("iocs_v2")
    op.drop_table("iocs")
    op.drop_table("subscriptions")
    op.drop_table("reports")
    op.drop_table("report_score_overrides")
    op.drop_table("ignore")
    op.drop_table("alerts")
    op.drop_table("feeds")
