"""create ignore report and ioc tables

Revision ID: e81292491222
Revises: 7e817801dc21
Create Date: 2018-08-02 08:39:59.620366

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "e81292491222"
down_revision = "7e817801dc21"
branch_labels = None
depends_on = None


def upgrade():

    op.create_table(
        "ignore_reports",
        sa.Column("org_id", sa.VARCHAR(), autoincrement=False, nullable=False),
        sa.Column("feed_id", sa.VARCHAR(), autoincrement=False, nullable=False),
        sa.Column("report_id", sa.VARCHAR(), autoincrement=False, nullable=False),
        sa.ForeignKeyConstraint(
            ["report_id", "feed_id"],
            ["reports.id", "reports.feed_id"],
            name="ignore_reports_report_id_fkey",
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint(
            "org_id", "feed_id", "report_id", name="ignore_reports_pkey"
        ),
    )

    op.create_table(
        "ignore_report_iocs",
        sa.Column("org_id", sa.VARCHAR(), autoincrement=False, nullable=False),
        sa.Column("feed_id", sa.VARCHAR(), autoincrement=False, nullable=False),
        sa.Column("report_id", sa.VARCHAR(), autoincrement=False, nullable=False),
        sa.Column("ioc_id", sa.VARCHAR(), autoincrement=False, nullable=False),
        sa.ForeignKeyConstraint(
            ["ioc_id", "report_id", "feed_id"],
            ["iocs_v2.id", "iocs_v2.report_id", "iocs_v2.feed_id"],
            name="ignore_report_iocs_ioc_id_fkey",
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint(
            "org_id", "feed_id", "report_id", "ioc_id", name="ignore_report_iocs_pkey"
        ),
    )

    op.execute(
        "INSERT INTO ignore_reports (org_id, feed_id, report_id) ("
        "  SELECT ignore.org_id, ignore.feed_id, ignore.report_id FROM ignore"
        "    WHERE ioc_id = '_PSCR_NONE_'"
        ");"
    )

    op.execute(
        "INSERT INTO ignore_report_iocs (org_id, feed_id, report_id, ioc_id) ("
        "  SELECT ignore.org_id, ignore.feed_id, ignore.report_id, ignore.ioc_id FROM ignore "
        "    WHERE ioc_id != '_PSCR_NONE_'"
        ");"
    )

    op.drop_table("ignore")


def downgrade():  # pragma: no cover
    op.create_table(
        "ignore",
        sa.Column("org_id", sa.VARCHAR(), autoincrement=False, nullable=False),
        sa.Column("feed_id", sa.VARCHAR(), autoincrement=False, nullable=False),
        sa.Column("report_id", sa.VARCHAR(), autoincrement=False, nullable=False),
        sa.Column("ioc_id", sa.VARCHAR(), autoincrement=False, nullable=False),
        sa.ForeignKeyConstraint(
            ["feed_id"], ["feeds.id"], name="ignore_feed_id_fkey", ondelete="CASCADE"
        ),
        sa.PrimaryKeyConstraint(
            "org_id", "feed_id", "report_id", "ioc_id", name="ignore_pkey"
        ),
    )

    op.execute(
        "INSERT INTO ignore (org_id, feed_id, report_id, ioc_id) ("
        "  SELECT ignore_reports.org_id, ignore_reports.feed_id, ignore_reports.report_id, '_PSCR_NONE_' "
        "    FROM ignore_reports"
        ");"
    )

    op.execute(
        "INSERT INTO ignore (org_id, feed_id, report_id, ioc_id) ("
        "  SELECT ignore_report_iocs.org_id, ignore_report_iocs.feed_id, ignore_report_iocs.report_id,"
        "    ignore_report_iocs.ioc_id FROM ignore_report_iocs"
        ");"
    )

    op.drop_table("ignore_reports")
    op.drop_table("ignore_report_iocs")
