import datetime
import logging
from typing import Iterable

import rapidjson

from pscr_common.utils import datetime_to_sec_timestamp
from pscr_common.aws import get_boto3_async_client

_logger = logging.getLogger(__name__)


def lookahead(iterable):
    it = iter(iterable)
    last = next(it)
    for val in it:
        # return previous value with more to come
        yield last, True
        last = val
    # return last value
    yield last, False


def json_datetime(obj):
    if isinstance(obj, datetime.datetime):
        return datetime_to_sec_timestamp(obj)
    else:
        raise ValueError("%r is not JSON serializable" % obj)


def unpack(obj):
    if isinstance(obj, dict):
        return {key: unpack(value) for key, value in obj.items()}
    elif isinstance(obj, list):
        return [unpack(value) for value in obj]
    elif hasattr(obj, "_asdict"):
        return {key: unpack(value) for key, value in obj._asdict().items()}
    elif isinstance(obj, tuple):
        return tuple(unpack(value) for value in obj)
    else:
        return obj


def json_dumps(obj, **kwargs):
    kwargs["datetime_mode"] = rapidjson.DM_UNIX_TIME | rapidjson.DM_ONLY_SECONDS
    return rapidjson.dumps(unpack(obj), **kwargs)


def aws_client(config, resource):
    return get_boto3_async_client(resource)


class lazy_join(object):
    def __init__(self, sep: str, items: Iterable[str]):
        self.sep = sep
        self.items = items

    def __str__(self):
        return self.sep.join(self.items)
